"""Test the sensors module model."""

from dataclasses import asdict

from syrupy.assertion import SnapshotAssertion

from systembridgemodels.fixtures.modules.sensors import FIXTURE_SENSORS
from systembridgemodels.modules.sensors import Sensors


def test_sensors(snapshot: SnapshotAssertion):
    """Test the sensors model."""
    sensors = FIXTURE_SENSORS
    assert isinstance(sensors, Sensors)
    assert sensors == snapshot


def test_sensors_dict(snapshot: SnapshotAssertion):
    """Test the sensors model to dict."""
    sensors_dict = asdict(FIXTURE_SENSORS)
    assert isinstance(sensors_dict, dict)
    assert sensors_dict == snapshot

    sensors_converted = Sensors(**sensors_dict)
    assert isinstance(sensors_converted, Sensors)
    assert sensors_converted == snapshot(
        name="sensors-dict-converted",
    )



"""Test the CPU module model."""

from dataclasses import asdict

from syrupy.assertion import SnapshotAssertion

from systembridgemodels.fixtures.modules.cpu import FIXTURE_CPU
from systembridgemodels.modules.cpu import CPU, PerCPU


def test_cpu(snapshot: SnapshotAssertion):
    """Test the CPU model."""
    cpu = FIXTURE_CPU
    assert isinstance(cpu, CPU)
    assert cpu == snapshot


def test_cpu_dict(snapshot: SnapshotAssertion):
    """Test CPU dict."""
    cpu_dict = asdict(FIXTURE_CPU)
    assert isinstance(cpu_dict, dict)
    assert cpu_dict == snapshot

    cpu_converted = CPU(**cpu_dict)
    assert isinstance(cpu_converted, CPU)
    assert cpu_converted == snapshot(
        name="cpu-dict-converted",
    )


def test_cpu_per_cpu_dict(snapshot: SnapshotAssertion):
    """Test CPU PerCPU dict."""
    assert isinstance(FIXTURE_CPU.per_cpu, list)

    per_cpu = FIXTURE_CPU.per_cpu[0]
    per_cpu_dict = asdict(per_cpu)
    assert isinstance(per_cpu_dict, dict)
    assert per_cpu_dict == snapshot

    per_cpu_converted = PerCPU(**per_cpu_dict)
    assert isinstance(per_cpu_converted, PerCPU)
    assert per_cpu_converted == snapshot(
        name="per-cpu-dict-converted",
    )



"""Test the networks module model."""

from dataclasses import asdict

from syrupy.assertion import SnapshotAssertion

from systembridgemodels.fixtures.modules.networks import FIXTURE_NETWORKS
from systembridgemodels.modules.networks import NetworkConnection, Networks


def test_networks(snapshot: SnapshotAssertion):
    """Test the networks model."""
    networks = FIXTURE_NETWORKS
    assert isinstance(networks, Networks)
    assert isinstance(networks.connections, list)
    assert isinstance(networks.connections[0], NetworkConnection)
    assert networks == snapshot


def test_networks_dict(snapshot: SnapshotAssertion):
    """Test the networks model to dict."""
    networks_dict = asdict(FIXTURE_NETWORKS)
    assert isinstance(networks_dict, dict)
    assert networks_dict == snapshot

    networks_converted = Networks(**networks_dict)
    assert isinstance(networks_converted, Networks)
    assert networks_converted == snapshot(
        name="networks-dict-converted",
    )



#!/usr/bin/env python3
"""Increment development version in setup.py.

If version is X.Y.Z.devN -> X.Y.Z.dev(N+1)
If version is X.Y.Z -> X.Y.(Z+1).dev0
"""

from __future__ import annotations

from pathlib import Path
import re


def main() -> None:
    """Increment development version in setup.py."""
    project_root = Path(__file__).resolve().parents[1]
    setup_path = project_root / "setup.py"
    contents = setup_path.read_text(encoding="utf-8")

    match = re.search(r'version="([^"]+)"', contents)
    if not match:
        raise SystemExit("version field not found in setup.py")

    version = match.group(1)
    dev_match = re.search(r"^(\d+)\.(\d+)\.(\d+)(?:\.dev(\d+))?$", version)
    if not dev_match:
        raise SystemExit(f"Unexpected version format: {version}")

    major, minor, patch, dev = dev_match.groups()
    if dev is None:
        new_version = f"{major}.{minor}.{int(patch) + 1}.dev0"
    else:
        new_version = f"{major}.{minor}.{patch}.dev{int(dev) + 1}"

    new_contents = contents.replace(
        f'version="{version}"', f'version="{new_version}"', 1
    )
    setup_path.write_text(new_contents, encoding="utf-8")
    print(f"Updated version to {new_version}")


if __name__ == "__main__":
    main()



"""Test the media module model."""

from syrupy.assertion import SnapshotAssertion

from systembridgemodels.fixtures.modules.media import FIXTURE_MEDIA
from systembridgemodels.modules.media import Media


def test_media(snapshot: SnapshotAssertion):
    """Test the media model."""
    media = FIXTURE_MEDIA
    assert isinstance(media, Media)
    assert media == snapshot



"""Test the networks module model."""

from syrupy.assertion import SnapshotAssertion

from systembridgemodels.fixtures.modules.system import FIXTURE_SYSTEM
from systembridgemodels.modules.system import System


def test_system(snapshot: SnapshotAssertion):
    """Test the system model."""
    system = FIXTURE_SYSTEM
    assert isinstance(system, System)
    assert system == snapshot



"""Test the displays module model."""

from syrupy.assertion import SnapshotAssertion

from systembridgemodels.fixtures.modules.displays import FIXTURE_DISPLAYS
from systembridgemodels.modules.displays import Display


def test_displays(snapshot: SnapshotAssertion):
    """Test the displays model."""
    displays = FIXTURE_DISPLAYS
    assert isinstance(displays, list)
    assert isinstance(displays[0], Display)
    assert displays == snapshot



#!/usr/bin/env python3
"""Ensure the package version in setup.py has a `.dev0` suffix.

If the version already includes a `.dev` suffix, no change is made.
"""

from __future__ import annotations

from pathlib import Path
import re


def main() -> None:
    """Ensure the package version in setup.py has a `.dev0` suffix."""
    project_root = Path(__file__).resolve().parents[1]
    setup_path = project_root / "setup.py"
    contents = setup_path.read_text(encoding="utf-8")

    match = re.search(r'version="([^"]+)"', contents)
    if not match:
        raise SystemExit("version field not found in setup.py")

    version = match.group(1)
    if "dev" in version:
        print("Version already has dev suffix, no change")
        return

    new_version = f"{version}.dev0"
    new_contents = contents.replace(f'version="{version}"', f'version="{new_version}"', 1)
    setup_path.write_text(new_contents, encoding="utf-8")
    print(f"Updated version to {new_version}")


if __name__ == "__main__":
    main()





"""Test the gpus module model."""

from syrupy.assertion import SnapshotAssertion

from systembridgemodels.fixtures.modules.gpus import FIXTURE_GPUS
from systembridgemodels.modules.gpus import GPU


def test_gpus(snapshot: SnapshotAssertion):
    """Test the GPUs model."""
    gpus = FIXTURE_GPUS
    assert isinstance(gpus, list)
    assert isinstance(gpus[0], GPU)
    assert gpus == snapshot



"""Test the networks module model."""

from syrupy.assertion import SnapshotAssertion

from systembridgemodels.fixtures.modules.processes import FIXTURE_PROCESSES
from systembridgemodels.modules.processes import Process


def test_networks(snapshot: SnapshotAssertion):
    """Test the processes model."""
    processes = FIXTURE_PROCESSES
    assert isinstance(processes, list)
    assert isinstance(processes[0], Process)
    assert processes == snapshot



"""Test the memory module model."""

from dataclasses import asdict

from syrupy.assertion import SnapshotAssertion

from systembridgemodels.fixtures.modules.memory import FIXTURE_MEMORY
from systembridgemodels.modules.memory import Memory


def test_memory(snapshot: SnapshotAssertion):
    """Test the memory model."""
    memory = FIXTURE_MEMORY
    assert isinstance(memory, Memory)
    assert memory == snapshot


def test_memory_dict(snapshot: SnapshotAssertion):
    """Test memory dict."""
    memory_dict = asdict(FIXTURE_MEMORY)
    assert isinstance(memory_dict, dict)
    assert memory_dict == snapshot

    memory_converted = Memory(**memory_dict)
    assert isinstance(memory_converted, Memory)
    assert memory_converted == snapshot(
        name="memory-dict-converted",
    )



"""Test the modules model."""

from systembridgemodels.modules import (
    GetData,
    Module,
    ModulesData,
    RegisterDataListener,
)

modules = [
    Module.BATTERY,
    Module.CPU,
    Module.DISKS,
    Module.DISPLAYS,
    Module.GPUS,
    Module.MEDIA,
    Module.MEMORY,
    Module.NETWORKS,
    Module.PROCESSES,
    Module.SENSORS,
    Module.SYSTEM,
]


def test_get_data():
    """Test get data."""
    get_data = GetData(
        modules=modules,
    )
    assert isinstance(get_data, GetData)
    assert get_data.modules == modules


def test_register_data_listener():
    """Test register data listener."""
    register_data_listener = RegisterDataListener(
        modules=modules,
    )
    assert isinstance(register_data_listener, RegisterDataListener)
    assert register_data_listener.modules == modules


def test_modules_data():
    """Test modules data."""
    modules_data = ModulesData()
    assert isinstance(modules_data, ModulesData)
    assert modules_data.battery is None
    assert modules_data.cpu is None
    assert modules_data.disks is None
    assert modules_data.displays is None
    assert modules_data.gpus is None
    assert modules_data.media is None
    assert modules_data.memory is None
    assert modules_data.networks is None
    assert modules_data.processes is None
    assert modules_data.sensors is None
    assert modules_data.system is None



#!/usr/bin/env python3
"""Strip any `.devN` suffix from the package version in setup.py."""

from __future__ import annotations

from pathlib import Path
import re


def main() -> None:
    """Strip any `.devN` suffix from the package version in setup.py."""
    project_root = Path(__file__).resolve().parents[1]
    setup_path = project_root / "setup.py"
    contents = setup_path.read_text(encoding="utf-8")

    match = re.search(r'version="([^"]+)"', contents)
    if not match:
        raise SystemExit("version field not found in setup.py")

    version = match.group(1)
    new_version = re.sub(r"\.dev\d*$", "", version)

    if new_version == version:
        print("No dev suffix to strip")
        return

    new_contents = contents.replace(f'version="{version}"', f'version="{new_version}"', 1)
    setup_path.write_text(new_contents, encoding="utf-8")
    print(f"Updated version to {new_version}")


if __name__ == "__main__":
    main()





#!/usr/bin/env python3
"""Print the current package version from setup.py.

This script reads the version string from the repository's setup.py and prints
only the version to stdout.
"""

from __future__ import annotations

from pathlib import Path
import re


def main() -> None:
    """Print the current package version from setup.py."""
    project_root = Path(__file__).resolve().parents[1]
    setup_path = project_root / "setup.py"
    setup_contents = setup_path.read_text(encoding="utf-8")
    match = re.search(r'version="([^"]+)"', setup_contents)
    if not match:
        raise SystemExit("version field not found in setup.py")
    print(match.group(1))


if __name__ == "__main__":
    main()





"""Test the battery module model."""

from syrupy.assertion import SnapshotAssertion

from systembridgemodels.fixtures.modules.battery import FIXTURE_BATTERY
from systembridgemodels.modules.battery import Battery


def test_battery(snapshot: SnapshotAssertion):
    """Test the battery model."""
    battery = FIXTURE_BATTERY
    assert isinstance(battery, Battery)
    assert battery == snapshot



"""Test the disks module model."""

from dataclasses import asdict

from syrupy.assertion import SnapshotAssertion

from systembridgemodels.fixtures.modules.disks import FIXTURE_DISKS
from systembridgemodels.modules.disks import (
    Disk,
    DiskIOCounters,
    DiskPartition,
    Disks,
    DiskUsage,
)


def _test_disk_partition(partition: DiskPartition):
    assert isinstance(partition, DiskPartition)
    assert partition.device == "device"
    assert partition.mount_point == "mountpoint"
    assert partition.filesystem_type == "fstype"
    assert partition.options == "options"
    assert partition.max_file_size == 1
    assert partition.max_path_length == 2
    assert isinstance(partition.usage, DiskUsage)
    assert partition.usage.total == 1
    assert partition.usage.used == 2
    assert partition.usage.free == 3
    assert partition.usage.percent == 40.2


def _test_disk(disk: Disk):
    assert isinstance(disk, Disk)
    assert disk.name == "name"
    assert isinstance(disk.partitions, list)
    assert isinstance(disk.partitions[0], DiskPartition)
    _test_disk_partition(disk.partitions[0])
    assert isinstance(disk.io_counters, DiskIOCounters)
    assert disk.io_counters.read_bytes == 1
    assert disk.io_counters.write_bytes == 2
    assert disk.io_counters.read_count == 3
    assert disk.io_counters.write_count == 4
    assert disk.io_counters.read_time == 5
    assert disk.io_counters.write_time == 6


def test_disks(snapshot: SnapshotAssertion):
    """Test the disks model."""
    disks = FIXTURE_DISKS
    assert isinstance(disks, Disks)
    assert disks == snapshot


def test_disks_dict(snapshot: SnapshotAssertion):
    """Test disks dict."""
    disks_dict = asdict(FIXTURE_DISKS)
    assert isinstance(disks_dict, dict)
    assert disks_dict == snapshot

    disks_converted = Disks(**disks_dict)
    assert isinstance(disks_converted, Disks)
    assert disks_converted == snapshot(
        name="disks-dict-converted",
    )


def test_disks_devices_dict(snapshot: SnapshotAssertion):
    """Test disks devices dict."""
    disk_dict = asdict(FIXTURE_DISKS.devices[0])
    assert isinstance(disk_dict, dict)
    assert disk_dict == snapshot

    disk_converted = Disk(**disk_dict)
    assert isinstance(disk_converted, Disk)
    assert disk_converted == snapshot(
        name="disks-devices-dict-converted",
    )


def test_disks_devices_partition_dict(snapshot: SnapshotAssertion):
    """Test disks devices partition dict."""
    partition_dict = asdict(FIXTURE_DISKS.devices[0].partitions[0])
    assert isinstance(partition_dict, dict)
    assert partition_dict == snapshot

    partition_converted = DiskPartition(**partition_dict)
    assert isinstance(partition_converted, DiskPartition)
    assert partition_converted == snapshot(
        name="disks-devices-partition-dict-converted",
    )



#!/usr/bin/env python3
"""Increment release version and set to next development cycle in setup.py.

X.Y.Z (or X.Y.Z.devN) -> X.Y.(Z+1).dev0
"""

from __future__ import annotations

from pathlib import Path
import re


def main() -> None:
    """Increment release version and set to next development cycle in setup.py."""
    project_root = Path(__file__).resolve().parents[1]
    setup_path = project_root / "setup.py"
    contents = setup_path.read_text(encoding="utf-8")

    match = re.search(r'version="([^"]+)"', contents)
    if not match:
        raise SystemExit("version field not found in setup.py")

    version = match.group(1)
    base = re.sub(r"\.dev\d*$", "", version)
    base_match = re.fullmatch(r"^(\d+)\.(\d+)\.(\d+)$", base)
    if not base_match:
        raise SystemExit(f"Unexpected base version format: {base}")

    major, minor, patch = base_match.groups()
    new_version = f"{major}.{minor}.{int(patch)+1}.dev0"

    new_contents = contents.replace(f'version="{version}"', f'version="{new_version}"', 1)
    setup_path.write_text(new_contents, encoding="utf-8")
    print(f"Updated version to {new_version}")


if __name__ == "__main__":
    main()


